@@ -1,8 +1,7 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 """
 Handles matplotlib styling in a single consistent place.
@@ -12,6 +11,10 @@ Handles matplotlib styling in a single consistent place.
 import warnings
 
 
+warnings.warn('The style module is deprecated and will be removed in a future release.',
+              DeprecationWarning, stacklevel=2)
+
+
 # Define the matplotlib style aliases that cartopy can expand.
 # Note: This should not contain the plural aliases
 # (e.g. linewidths -> linewidth).
