@@ -1,8 +1,7 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 from xml.etree.ElementTree import ParseError
 
 import matplotlib.pyplot as plt
@@ -10,7 +9,11 @@ import pytest
 
 import cartopy.crs as ccrs
 import cartopy.feature as cfeature
-from cartopy.io.ogc_clients import _OWSLIB_AVAILABLE
+from cartopy.tests.conftest import _HAS_PYKDTREE_OR_SCIPY
+
+
+if _HAS_PYKDTREE_OR_SCIPY:
+    from cartopy.io.ogc_clients import _OWSLIB_AVAILABLE
 
 
 @pytest.mark.filterwarnings("ignore:Downloading")
@@ -43,6 +46,8 @@ def test_natural_earth_custom():
     return ax.figure
 
 
+@pytest.mark.network
+@pytest.mark.skipif(not _HAS_PYKDTREE_OR_SCIPY, reason='pykdtree or scipy is required')
 @pytest.mark.mpl_image_compare(filename='gshhs_coastlines.png', tolerance=0.95)
 def test_gshhs():
     ax = plt.axes(projection=ccrs.Mollweide())
@@ -58,7 +63,8 @@ def test_gshhs():
 
 
 @pytest.mark.network
-@pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
+@pytest.mark.skipif(not _HAS_PYKDTREE_OR_SCIPY or not _OWSLIB_AVAILABLE,
+                    reason='OWSLib and at least one of pykdtree or scipy is required')
 @pytest.mark.xfail(raises=ParseError,
                    reason="Bad XML returned from the URL")
 @pytest.mark.mpl_image_compare(filename='wfs.png')
@@ -73,13 +79,15 @@ def test_wfs():
 
 
 @pytest.mark.network
-@pytest.mark.skipif(not _OWSLIB_AVAILABLE, reason='OWSLib is unavailable.')
-@pytest.mark.xfail(raises=ParseError,
+@pytest.mark.skipif(not _HAS_PYKDTREE_OR_SCIPY or not _OWSLIB_AVAILABLE,
+                    reason='OWSLib and at least one of pykdtree or scipy is required')
+@pytest.mark.xfail(raises=(ParseError, AttributeError),
                    reason="Bad XML returned from the URL")
+@pytest.mark.xfail(reason="Unauthorized access to the WFS service")
 @pytest.mark.mpl_image_compare(filename='wfs_france.png')
 def test_wfs_france():
     ax = plt.axes(projection=ccrs.epsg(2154))
-    url = 'https://agroenvgeo.data.inra.fr:443/geoserver/wfs'
+    url = 'https://geodata.inrae.fr/geoserver/wfs'
     typename = 'collectif:t_ser_l93'
     feature = cfeature.WFSFeature(url, typename, edgecolor='red')
     ax.add_feature(feature)
