@@ -1,20 +1,24 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 import re
 
 import matplotlib.colors as mcolors
 import matplotlib.pyplot as plt
 import numpy as np
+from packaging.version import parse as parse_version
+import pyproj
 import pytest
 
 import cartopy.crs as ccrs
-from cartopy.tests.mpl import MPL_VERSION
+from cartopy.mpl import _MPL_38
+from cartopy.tests.conftest import requires_scipy
 
 
+proj_version = parse_version(pyproj.proj_version_str)
+
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='global_contour_wrap.png',
                                style='mpl20', tolerance=2.25)
@@ -22,7 +26,7 @@ def test_global_contour_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.contour(x, y, data, transform=ccrs.PlateCarree())
     return ax.figure
 
@@ -34,7 +38,7 @@ def test_global_contour_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.contour(x, y, data)
     return ax.figure
 
@@ -45,7 +49,7 @@ def test_global_contourf_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.contourf(x, y, data, transform=ccrs.PlateCarree())
     return ax.figure
 
@@ -56,7 +60,7 @@ def test_global_contourf_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.contourf(x, y, data)
     return ax.figure
 
@@ -67,7 +71,7 @@ def test_global_pcolor_wrap_new_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))[:-1, :-1]
+    data = np.sin(np.hypot(x, y))[:-1, :-1]
     ax.pcolor(x, y, data, transform=ccrs.PlateCarree())
     return ax.figure
 
@@ -78,7 +82,7 @@ def test_global_pcolor_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines()
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))[:-1, :-1]
+    data = np.sin(np.hypot(x, y))[:-1, :-1]
     ax.pcolor(x, y, data)
     return ax.figure
 
@@ -92,7 +96,7 @@ def test_global_scatter_wrap_new_transform():
     # after the coastlines.
     ax.coastlines(zorder=0)
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.scatter(x, y, c=data, transform=ccrs.PlateCarree())
     return ax.figure
 
@@ -103,7 +107,7 @@ def test_global_scatter_wrap_no_transform():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines(zorder=0)
     x, y = np.meshgrid(np.linspace(0, 360), np.linspace(-90, 90))
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     ax.scatter(x, y, c=data)
     return ax.figure
 
@@ -114,7 +118,7 @@ def test_global_hexbin_wrap():
     ax = plt.axes(projection=ccrs.PlateCarree())
     ax.coastlines(zorder=2)
     x, y = np.meshgrid(np.arange(-179, 181), np.arange(-90, 91))
-    data = np.sin(np.sqrt(x**2 + y**2))
+    data = np.sin(np.hypot(x, y))
     ax.hexbin(
         x.flatten(),
         y.flatten(),
@@ -135,7 +139,7 @@ def test_global_hexbin_wrap_transform():
     x, y = np.meshgrid(np.arange(0, 360), np.arange(-90, 91))
     # wrap values so to match x values from test_global_hexbin_wrap
     x_wrap = np.where(x >= 180, x - 360, x)
-    data = np.sin(np.sqrt(x_wrap**2 + y**2))
+    data = np.sin(np.hypot(x_wrap, y))
     ax.hexbin(
         x.flatten(),
         y.flatten(),
@@ -172,6 +176,11 @@ def test_simple_global():
     pytest.param((ccrs.InterruptedGoodeHomolosine, dict(emphasis='land')),
                  id='InterruptedGoodeHomolosine'),
     ccrs.LambertCylindrical,
+    ccrs.LambertZoneII,
+    pytest.param(ccrs.Spilhaus,marks=pytest.mark.skipif(
+            (proj_version < parse_version("9.6.0")),
+            reason="Requires PROJ >= 9.6.0"
+        )),
     pytest.param((ccrs.Mercator, dict(min_latitude=-85, max_latitude=85)),
                  id='Mercator'),
     ccrs.Miller,
@@ -196,9 +205,7 @@ def test_simple_global():
         id='ObliqueMercator_rotated',
     ),
 ])
-@pytest.mark.mpl_image_compare(
-    tolerance=0.97 if MPL_VERSION.release[:2] < (3, 5) else 0.5,
-    style='mpl20')
+@pytest.mark.mpl_image_compare(style='mpl20')
 def test_global_map(proj):
     if isinstance(proj, tuple):
         proj, kwargs = proj
@@ -241,8 +248,7 @@ def test_cursor_values():
                      r.encode('ascii', 'ignore'))
 
 
-SKIP_PRE_MPL38 = pytest.mark.skipif(
-    MPL_VERSION.release[:2] < (3, 8), reason='mpl < 3.8')
+SKIP_PRE_MPL38 = pytest.mark.skipif(not _MPL_38, reason='mpl < 3.8')
 PARAMETRIZE_PCOLORMESH_WRAP = pytest.mark.parametrize(
     'mesh_data_kind',
     [
@@ -357,7 +363,7 @@ def test_pcolormesh_get_array_with_mask(mesh_data_kind):
     result = c.get_array()
 
     expected = data2
-    if MPL_VERSION.release[:2] < (3, 8):
+    if not _MPL_38:
         expected = expected.ravel()
 
     np.testing.assert_array_equal(np.ma.getmask(result), np.isnan(expected))
@@ -521,7 +527,7 @@ def test_pcolormesh_set_array_nowrap():
     assert not hasattr(mesh, '_wrapped_collection_fix')
 
     expected = data
-    if MPL_VERSION.release[:2] < (3, 8):
+    if not _MPL_38:
         expected = expected.ravel()
     np.testing.assert_array_equal(mesh.get_array(), expected)
 
@@ -588,7 +594,7 @@ def test_pcolormesh_set_clim_with_mask():
 
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='pcolormesh_limited_area_wrap.png',
-                               tolerance=1.82)
+                               tolerance=1.83)
 def test_pcolormesh_limited_area_wrap():
     # make up some realistic data with bounds (such as data from the UM's North
     # Atlantic Europe model)
@@ -657,6 +663,17 @@ def test_pcolormesh_single_column_wrap():
     return fig
 
 
+def test_pcolormesh_wrap_gouraud_shading_failing_mask_creation():
+    x_range = np.linspace(-180, 180, 50)
+    y_range = np.linspace(90, -90, 50)
+    x, y = np.meshgrid(x_range, y_range)
+    data = ((np.sin(np.deg2rad(x))) / 10. + np.exp(np.cos(np.deg2rad(y))))
+
+    fig = plt.figure(figsize=(10, 6))
+    ax = fig.add_subplot(1, 1, 1, projection=ccrs.Mercator())
+    ax.pcolormesh(x, y, data, transform=ccrs.PlateCarree(), shading='gouraud')
+
+
 def test_pcolormesh_diagonal_wrap():
     # Check that a cell with the top edge on one side of the domain
     # and the bottom edge on the other gets wrapped properly
@@ -681,7 +698,7 @@ def test_pcolormesh_nan_wrap():
     ax = plt.axes(projection=ccrs.PlateCarree())
     mesh = ax.pcolormesh(xs, ys, data)
     pcolor = getattr(mesh, "_wrapped_collection_fix")
-    if MPL_VERSION.release[:2] < (3, 8):
+    if not _MPL_38:
         assert len(pcolor.get_paths()) == 2
     else:
         assert not pcolor.get_paths()
@@ -765,9 +782,24 @@ def test_pcolormesh_shading(shading, input_size, expected):
     d = np.zeros((3, 3))
 
     coll = ax.pcolormesh(x, y, d, shading=shading)
-    # We can use coll.get_coordinates() once MPL >= 3.5 is required
-    # For now, we use the private variable for testing
-    assert coll._coordinates.shape == (expected, expected, 2)
+    assert coll.get_coordinates().shape == (expected, expected, 2)
+
+
+def test__wrap_args_default_shading():
+    # Passing shading=None should give the same as not passing the shading parameter.
+    x = np.linspace(0, 360, 12)
+    y = np.linspace(0, 90, 5)
+    z = np.zeros((12, 5))
+
+    ax = plt.subplot(projection=ccrs.Orthographic())
+    args_ref, kwargs_ref = ax._wrap_args(x, y, z, transform=ccrs.PlateCarree())
+    args_test, kwargs_test = ax._wrap_args(
+        x, y, z, transform=ccrs.PlateCarree(), shading=None)
+
+    for array_ref, array_test in zip(args_ref, args_test):
+        np.testing.assert_allclose(array_ref, array_test)
+
+    assert kwargs_ref == kwargs_test
 
 
 @pytest.mark.natural_earth
@@ -778,7 +810,7 @@ def test_quiver_plate_carree():
     x2d, y2d = np.meshgrid(x, y)
     u = np.cos(np.deg2rad(y2d))
     v = np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     fig = plt.figure(figsize=(6, 6))
     # plot on native projection
@@ -803,7 +835,7 @@ def test_quiver_rotated_pole():
     x2d, y2d = np.meshgrid(x, y)
     u = np.cos(np.deg2rad(y2d))
     v = -2. * np.cos(2. * np.deg2rad(y2d)) * np.sin(np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     rp = ccrs.RotatedPole(pole_longitude=177.5, pole_latitude=37.5)
     plot_extent = [x[0], x[-1], y[0], y[-1]]
     # plot on native projection
@@ -820,6 +852,7 @@ def test_quiver_rotated_pole():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='quiver_regrid.png')
 def test_quiver_regrid():
@@ -828,7 +861,7 @@ def test_quiver_regrid():
     x2d, y2d = np.meshgrid(x, y)
     u = np.cos(np.deg2rad(y2d))
     v = np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     fig = plt.figure(figsize=(6, 3))
     ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
@@ -839,6 +872,7 @@ def test_quiver_regrid():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='quiver_regrid_with_extent.png',
                                tolerance=0.54)
@@ -848,7 +882,7 @@ def test_quiver_regrid_with_extent():
     x2d, y2d = np.meshgrid(x, y)
     u = np.cos(np.deg2rad(y2d))
     v = np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     target_extent = [-3e6, 2e6, -6e6, -2.5e6]
     fig = plt.figure(figsize=(6, 3))
@@ -860,6 +894,7 @@ def test_quiver_regrid_with_extent():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='barbs_plate_carree.png')
 def test_barbs():
@@ -883,6 +918,7 @@ def test_barbs():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='barbs_regrid.png')
 def test_barbs_regrid():
@@ -891,7 +927,7 @@ def test_barbs_regrid():
     x2d, y2d = np.meshgrid(x, y)
     u = 40 * np.cos(np.deg2rad(y2d))
     v = 40 * np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     fig = plt.figure(figsize=(6, 3))
     ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
@@ -902,6 +938,7 @@ def test_barbs_regrid():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='barbs_regrid_with_extent.png',
                                tolerance=0.54)
@@ -911,7 +948,7 @@ def test_barbs_regrid_with_extent():
     x2d, y2d = np.meshgrid(x, y)
     u = 40 * np.cos(np.deg2rad(y2d))
     v = 40 * np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     target_extent = [-3e6, 2e6, -6e6, -2.5e6]
     fig = plt.figure(figsize=(6, 3))
@@ -958,17 +995,16 @@ def test_barbs_1d_transformed():
     return fig
 
 
+@requires_scipy
 @pytest.mark.natural_earth
-@pytest.mark.mpl_image_compare(
-    filename='streamplot.png', style='mpl20',
-    tolerance=9.77 if MPL_VERSION.release[:2] < (3, 5) else 0.5)
+@pytest.mark.mpl_image_compare(filename='streamplot.png', style='mpl20')
 def test_streamplot():
     x = np.arange(-60, 42.5, 2.5)
     y = np.arange(30, 72.5, 2.5)
     x2d, y2d = np.meshgrid(x, y)
     u = np.cos(np.deg2rad(y2d))
     v = np.cos(2. * np.deg2rad(x2d))
-    mag = (u**2 + v**2)**.5
+    mag = np.hypot(u, v)
     plot_extent = [-60, 40, 30, 70]
     fig = plt.figure(figsize=(6, 3))
     ax = fig.add_subplot(projection=ccrs.NorthPolarStereo())
@@ -1021,7 +1057,7 @@ def test_annotate():
     ax.annotate('default crs', map_coords, size=5)
 
     # data in map projection using default transform, with
-    # text positioned in platecaree transform
+    # text positioned in platecarree transform
     ax.annotate('mixed crs transforms', map_coords, xycoords='data',
                 xytext=(-175, -55),
                 textcoords=platecarree,
@@ -1044,3 +1080,9 @@ def test_annotate():
                 )
 
     return fig
+
+
+def test_inset_axes():
+    fig, ax = plt.subplots()
+    ax.inset_axes([0.75, 0.75, 0.25, 0.25], projection=ccrs.PlateCarree())
+    fig.draw_without_rendering()
