@@ -1,8 +1,7 @@
-# Copyright Cartopy Contributors
+# Copyright Crown and Cartopy Contributors
 #
-# This file is part of Cartopy and is released under the LGPL license.
-# See COPYING and COPYING.LESSER in the root of the repository for full
-# licensing details.
+# This file is part of Cartopy and is released under the BSD 3-clause license.
+# See LICENSE in the root of the repository for full licensing details.
 
 from matplotlib.collections import PatchCollection
 import matplotlib.patches as mpatches
@@ -14,13 +13,15 @@ import shapely.geometry as sgeom
 
 import cartopy.crs as ccrs
 import cartopy.mpl.patch as cpatch
+import cartopy.mpl.path as cpath
 
 
 # Note: Matplotlib is broken here
 # https://github.com/matplotlib/matplotlib/issues/15946
 @pytest.mark.natural_earth
 @pytest.mark.mpl_image_compare(filename='poly_interiors.png', tolerance=3.1)
-def test_polygon_interiors():
+@pytest.mark.parametrize('use_legacy_geos_funcs', [False, True])
+def test_polygon_interiors(use_legacy_geos_funcs):
     fig = plt.figure()
 
     ax = fig.add_subplot(2, 1, 1, projection=ccrs.PlateCarree())
@@ -31,16 +32,29 @@ def test_polygon_interiors():
                 [10, -20], [10, 20], [40, 20], [40, -20], [10, 20]],
                [1, 2, 2, 2, 79, 1, 2, 2, 2, 79])
 
-    patches_native = []
-    patches = []
-    for geos in cpatch.path_to_geos(pth):
-        for pth in cpatch.geos_to_path(geos):
-            patches.append(mpatches.PathPatch(pth))
+    if use_legacy_geos_funcs:
+        patches_native = []
+        patches = []
+        with pytest.warns(DeprecationWarning, match="path_to_geos is deprecated"):
+            for geos in cpatch.path_to_geos(pth):
+                with pytest.warns(DeprecationWarning, match="geos_to_path is deprecat"):
+                    for pth in cpatch.geos_to_path(geos):
+                        patches.append(mpatches.PathPatch(pth))
 
-        # buffer by 10 degrees (leaves a small hole in the middle)
-        geos_buffered = geos.buffer(10)
-        for pth in cpatch.geos_to_path(geos_buffered):
-            patches_native.append(mpatches.PathPatch(pth))
+                # buffer by 10 degrees (leaves a small hole in the middle)
+                geos_buffered = geos.buffer(10)
+                with pytest.warns(DeprecationWarning, match="geos_to_path is deprecat"):
+                    for pth in cpatch.geos_to_path(geos_buffered):
+                        patches_native.append(mpatches.PathPatch(pth))
+    else:
+        geom = cpath.path_to_shapely(pth)
+        assert isinstance(geom, sgeom.Polygon)
+        path = cpath.shapely_to_path(geom)
+        patches = [mpatches.PathPatch(path)]
+
+        geom_buffered = geom.buffer(10)
+        path_buffered = cpath.shapely_to_path(geom_buffered)
+        patches_native = [mpatches.PathPatch(path_buffered)]
 
     # Set high zorder to ensure the polygons are drawn on top of coastlines.
     collection = PatchCollection(patches_native, facecolor='red', alpha=0.4,
@@ -62,9 +76,14 @@ def test_polygon_interiors():
                  np.array(sgeom.box(1, 8, 2, 9, ccw=False).exterior.coords)]
     poly = sgeom.Polygon(exterior, interiors)
 
-    patches = []
-    for pth in cpatch.geos_to_path(poly):
-        patches.append(mpatches.PathPatch(pth))
+    if use_legacy_geos_funcs:
+        patches = []
+        with pytest.warns(DeprecationWarning, match="geos_to_path is deprecated"):
+            for pth in cpatch.geos_to_path(poly):
+                patches.append(mpatches.PathPatch(pth))
+    else:
+        path = cpath.shapely_to_path(poly)
+        patches = [mpatches.PathPatch(path)]
 
     collection = PatchCollection(patches, facecolor='yellow', alpha=0.4,
                                  transform=ccrs.Geodetic(), zorder=10)
@@ -81,7 +100,7 @@ def test_contour_interiors():
     numlev = 2
     lons, lats = np.meshgrid(np.linspace(-50, 50, nx),
                              np.linspace(-45, 45, ny))
-    data = np.sin(np.sqrt(lons ** 2 + lats ** 2))
+    data = np.sin(np.hypot(lons, lats))
     fig = plt.figure()
 
     ax = fig.add_subplot(2, 2, 1, projection=ccrs.PlateCarree())
@@ -99,7 +118,7 @@ def test_contour_interiors():
     numlev = 2
     x, y = np.meshgrid(np.arange(-5.5, 5.5, 0.25), np.arange(-5.5, 5.5, 0.25))
     dim = x.shape[0]
-    data = np.sin(np.sqrt(x ** 2 + y ** 2))
+    data = np.sin(np.hypot(x, y))
     lats = np.arange(dim) + 30
     lons = np.arange(dim) - 20
 
